==> react-form-builder-4.45.0.tgz: package/lib/Stepper/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { isValidElement, memo } from 'react';
import PropTypes from 'prop-types';
import { field, createComponentMemo } from '../prop-types';
import MoleculeDataCounter from '@s-ui/react-molecule-data-counter';
import { jsx as _jsx } from "react/jsx-runtime";
export var OPERATIONS = {
  ADD: '+',
  SUBSTRACT: '-'
};

var Stepper = function Stepper(_ref) {
  var stepper = _ref.stepper,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      errors = _ref.errors,
      alerts = _ref.alerts,
      renderer = _ref.renderer;
  var errorMessages = errors[stepper.id];
  var alertMessages = alerts[stepper.id];

  var onChangeHandler = function onChangeHandler(__, _ref2) {
    var value = _ref2.value;
    return onChange(stepper.id, value);
  };

  var stepperProps = _extends({
    id: stepper.id,
    inputDisabled: stepper.inputDisabled,
    label: stepper.label,
    max: stepper.max,
    maxValueErrorText: stepper.maxValueErrorText,
    min: stepper.min,
    minValueErrorText: stepper.minValueErrorText,
    tabIndex: tabIndex,
    value: stepper.value
  }, stepper.disabled && {
    disabled: true
  }, stepper.hidden && {
    hidden: true
  }, !!errorMessages && {
    errorText: errorMessages.join('\n')
  }, !!alertMessages && {
    alertText: alertMessages.join('\n')
  });

  if (stepperProps.hidden) {
    return null;
  }

  var rendererResponse = renderer({
    id: stepper.id,
    innerProps: _extends({}, stepperProps)
  }); // render custom component

  if ( /*#__PURE__*/isValidElement(rendererResponse)) return rendererResponse; // render SUI component

  return /*#__PURE__*/_jsx("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-Stepper sui-FormBuilder-" + (stepperProps.id || tabIndex),
    children: /*#__PURE__*/_jsx(MoleculeDataCounter, _extends({}, stepperProps, {
      onChange: onChangeHandler
    }))
  });
};

Stepper.displayName = 'Stepper';
export default /*#__PURE__*/memo(Stepper, createComponentMemo('stepper'));

==> react-form-builder-5.3.0.tgz: package/lib/Stepper/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { isValidElement, memo } from 'react';
import PropTypes from 'prop-types';
import { field, createComponentMemo } from '../prop-types/index.js';
import MoleculeDataCounter from '@s-ui/react-molecule-data-counter';
import { jsx as _jsx } from "react/jsx-runtime";
export var OPERATIONS = {
  ADD: '+',
  SUBSTRACT: '-'
};

var Stepper = function Stepper(_ref) {
  var stepper = _ref.stepper,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      errors = _ref.errors,
      alerts = _ref.alerts,
      renderer = _ref.renderer;
  var errorMessages = errors[stepper.id];
  var alertMessages = alerts[stepper.id];

  var onChangeHandler = function onChangeHandler(__, _ref2) {
    var value = _ref2.value;
    return onChange(stepper.id, value);
  };

  var stepperProps = _extends({
    id: stepper.id,
    inputDisabled: stepper.inputDisabled,
    label: stepper.label,
    max: stepper.max,
    maxValueErrorText: stepper.maxValueErrorText,
    min: stepper.min,
    minValueErrorText: stepper.minValueErrorText,
    tabIndex: tabIndex,
    value: stepper.value
  }, stepper.disabled && {
    disabled: true
  }, stepper.hidden && {
    hidden: true
  }, !!errorMessages && {
    errorText: errorMessages.join('\n')
  }, !!alertMessages && {
    alertText: alertMessages.join('\n')
  });

  if (stepperProps.hidden) {
    return null;
  }

  var rendererResponse = renderer({
    id: stepper.id,
    innerProps: _extends({}, stepperProps)
  }); // render custom component

  if ( /*#__PURE__*/isValidElement(rendererResponse)) return rendererResponse; // render SUI component

  return /*#__PURE__*/_jsx("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-Stepper sui-FormBuilder-" + (stepperProps.id || tabIndex),
    children: /*#__PURE__*/_jsx(MoleculeDataCounter, _extends({}, stepperProps, rendererResponse, {
      onChange: onChangeHandler
    }))
  });
};

Stepper.displayName = 'Stepper';
export default /*#__PURE__*/memo(Stepper, createComponentMemo('stepper'));
